==> aom-docs-3.3.0-1-x86_64.pkg.tar.zst: usr/share/doc/aom/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "AOMedia AV1 Codec", "index.html", [
    [ "AOMedia Codec SDK", "index.html#aom_sdk", [
      [ "Introduction", "index.html#main_intro", null ],
      [ "Starting Points", "index.html#main_startpoints", null ]
    ] ],
    [ "AV1 Developer's Guide", "index.html#av1_guide", null ],
    [ "Support Options & FAQ", "index.html#main_support", null ],
    [ "RFC2119 Keywords", "rfc2119.html", [
      [ "MUST", "rfc2119.html#MUST", null ],
      [ "MUST NOT", "rfc2119.html#MUSTNOT", null ],
      [ "SHOULD", "rfc2119.html#SHOULD", null ],
      [ "SHOULD NOT", "rfc2119.html#SHOULDNOT", null ],
      [ "MAY", "rfc2119.html#MAY", null ]
    ] ],
    [ "CHANGELOG", "changelog.html", null ],
    [ "README.md", "readme.html", null ],
    [ "Usage", "usage.html", "usage" ],
    [ "AV1 DECODER GUIDE", "decoder_guide.html", null ],
    [ "AV1 ENCODER GUIDE", "encoder_guide.html", [
      [ "Introduction", "encoder_guide.html#architecture_introduction", [
        [ "Generic Block Transform Based Codecs", "encoder_guide.html#architecture_gencodecs", null ],
        [ "AV1 Structure and Complexity", "encoder_guide.html#architecture_av1_structure", null ]
      ] ],
      [ "The Libaom Command Line Interface", "encoder_guide.html#architecture_command_line", null ],
      [ "Main Encoder Data Structures", "encoder_guide.html#architecture_enc_data_structures", null ],
      [ "Encoder Use Cases", "encoder_guide.html#architecture_enc_use_cases", null ],
      [ "Speed vs Quality Trade Off", "encoder_guide.html#architecture_enc_speed_quality", null ],
      [ "Source Frame Processing", "encoder_guide.html#architecture_enc_src_proc", [
        [ "Main Data Structures", "encoder_guide.html#architecture_enc_frame_proc_data", null ],
        [ "Frame Ingest / Coding Pipeline", "encoder_guide.html#architecture_enc_frame_proc_ingest", null ],
        [ "Temporal Filtering", "encoder_guide.html#architecture_enc_frame_proc_tf", [
          [ "Overview", "encoder_guide.html#architecture_enc_frame_proc_tf_overview", null ],
          [ "Temporal Filtering Algorithm", "encoder_guide.html#architecture_enc_frame_proc_tf_algo", null ],
          [ "Temporal Filter Functions", "encoder_guide.html#architecture_enc_frame_proc_tf_funcs", null ]
        ] ],
        [ "Film Grain Modelling", "encoder_guide.html#architecture_enc_frame_proc_film", null ]
      ] ],
      [ "Rate Control", "encoder_guide.html#architecture_enc_rate_ctrl", [
        [ "Main Data Structures", "encoder_guide.html#architecture_enc_rate_ctrl_data", null ],
        [ "Supported Rate Control Options", "encoder_guide.html#architecture_enc_rate_ctrl_options", null ],
        [ "Variable Bitrate (VBR) Encoding", "encoder_guide.html#architecture_enc_vbr", [
          [ "1 Pass VBR Encoding", "encoder_guide.html#architecture_enc_1pass_vbr", null ],
          [ "2 Pass VBR Encoding", "encoder_guide.html#architecture_enc_2pass_vbr", null ],
          [ "1 Pass Lagged VBR Encoding", "encoder_guide.html#architecture_enc_1pass_lagged", null ]
        ] ],
        [ "The Main Rate Control Loop", "encoder_guide.html#architecture_enc_rc_loop", null ],
        [ "Fixed Q Mode", "encoder_guide.html#architecture_enc_fixed_q", null ]
      ] ],
      [ "GF/ ARF Frame Groups & Hierarchical Coding", "encoder_guide.html#architecture_enc_frame_groups", [
        [ "Main Data Structures", "encoder_guide.html#architecture_enc_frame_groups_data", null ],
        [ "Frame Groups", "encoder_guide.html#architecture_enc_frame_groups_groups", null ],
        [ "GF / ARF Group Length Determination", "encoder_guide.html#architecture_enc_gf_length", null ],
        [ "Defining a GF Group's Structure", "encoder_guide.html#architecture_enc_gf_structure", null ],
        [ "Key Frame Groups", "encoder_guide.html#architecture_enc_kf_groups", null ]
      ] ],
      [ "Temporal Dependency Modelling", "encoder_guide.html#architecture_enc_tpl", [
        [ "Configurations", "encoder_guide.html#architecture_enc_tpl_config", null ],
        [ "Algorithms", "encoder_guide.html#architecture_enc_tpl_algoritms", null ],
        [ "Key Functions and data structures", "encoder_guide.html#architecture_enc_tpl_keyfun", null ]
      ] ],
      [ "Block Partition Search", "encoder_guide.html#architecture_enc_partitions", null ],
      [ "Intra Mode Search", "encoder_guide.html#architecture_enc_intra_modes", null ],
      [ "Inter Prediction Mode Search", "encoder_guide.html#architecture_enc_inter_modes", null ],
      [ "Transform Search", "encoder_guide.html#architecture_enc_tx_search", null ],
      [ "Post Encode Loop Filtering", "encoder_guide.html#architecture_post_enc_filt", null ],
      [ "Entropy Coding", "encoder_guide.html#architecture_entropy", [
        [ "Arithmetic Coder", "encoder_guide.html#architecture_entropy_aritmetic", null ],
        [ "Transform Coefficient Coding and Optimization", "encoder_guide.html#architecture_entropy_coef", [
          [ "Transform coefficient coding", "encoder_guide.html#architecture_entropy_coef_what", [
            [ "Preparation - transform and quantize", "encoder_guide.html#architecture_entropy_coef_prepare", null ],
            [ "The coding process", "encoder_guide.html#architecture_entropy_coef_coding", null ],
            [ "Context information", "encoder_guide.html#architecture_entropy_coef_context", null ]
          ] ],
          [ "RD optimization", "encoder_guide.html#architecture_entropy_coef_rd", [
            [ "Entropy cost", "encoder_guide.html#architecture_entropy_coef_cost", null ],
            [ "Quantized level optimization", "encoder_guide.html#architecture_entropy_coef_opt", null ]
          ] ]
        ] ]
      ] ]
    ] ],
    [ "Sample Code", "samples.html", "samples" ],
    [ "README.md", "LREADME.html", [
      [ "AV1 Codec Library", "LREADME.html#autotoc_md0", [
        [ "Contents", "LREADME.html#autotoc_md1", null ],
        [ "Building the library and applications", "LREADME.html#building-the-library-and-applications", [
          [ "Prerequisites", "LREADME.html#prerequisites", null ],
          [ "Get the code", "LREADME.html#get-the-code", null ],
          [ "Basic build", "LREADME.html#basic-build", null ],
          [ "Configuration options", "LREADME.html#configuration-options", null ],
          [ "Dylib builds", "LREADME.html#dylib-builds", null ],
          [ "Debugging", "LREADME.html#debugging", null ],
          [ "Cross compiling", "LREADME.html#cross-compiling", null ],
          [ "Sanitizers", "LREADME.html#sanitizers", null ],
          [ "Microsoft Visual Studio builds", "LREADME.html#microsoft-visual-studio-builds", null ],
          [ "Xcode builds", "LREADME.html#xcode-builds", null ],
          [ "Emscripten builds", "LREADME.html#emscripten-builds", null ],
          [ "Extra build flags", "LREADME.html#extra-build-flags", null ],
          [ "Build with VMAF support", "LREADME.html#build-with-vmaf", null ]
        ] ],
        [ "Testing the AV1 codec", "LREADME.html#testing-the-av1-codec", [
          [ "Testing basics", "LREADME.html#testing-basics", [
            [ "1. Unit tests: {#1_unit-tests}", "LREADME.html#autotoc_md2", null ],
            [ "2. Example tests: {#2_example-tests}", "LREADME.html#autotoc_md3", null ],
            [ "3. Encoder tests: {#3_encoder-tests}", "LREADME.html#autotoc_md4", null ]
          ] ],
          [ "IDE hosted tests", "LREADME.html#ide-hosted-tests", null ],
          [ "Downloading the test data", "LREADME.html#downloading-the-test-data", null ],
          [ "Adding a new test data file", "LREADME.html#adding-a-new-test-data-file", null ],
          [ "Additional test data", "LREADME.html#additional-test-data", null ],
          [ "Sharded testing", "LREADME.html#sharded-testing", [
            [ "1. Running test_libaom directly: {#1_running-test_libaom-directly}", "LREADME.html#autotoc_md5", null ],
            [ "2. Running the tests via the CMake build: {#2_running-the-tests-via-the-cmake-build}", "LREADME.html#autotoc_md6", null ]
          ] ]
        ] ],
        [ "Coding style", "LREADME.html#coding-style", null ],
        [ "Submitting patches", "LREADME.html#submitting-patches", [
          [ "Login cookie", "LREADME.html#login-cookie", null ],
          [ "Contributor agreement", "LREADME.html#contributor-agreement", null ],
          [ "Testing your code", "LREADME.html#testing-your-code", null ],
          [ "Commit message hook", "LREADME.html#commit-message-hook", null ],
          [ "Upload your change", "LREADME.html#upload-your-change", null ],
          [ "Incorporating reviewer comments", "LREADME.html#incorporating-reviewer-comments", null ],
          [ "Submitting your change", "LREADME.html#submitting-your-change", null ],
          [ "Viewing the status of uploaded changes", "LREADME.html#viewing-the-status-of-uploaded-changes", null ]
        ] ],
        [ "Support", "LREADME.html#support", null ],
        [ "Bug reports", "LREADME.html#bug-reports", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"LREADME.html",
"encoder_guide.html#architecture_entropy_coef",
"group__aom__encoder.html#gadbb2fdd04ce113cdf455a6ea49109d41",
"group__decoder.html#gab2bfd2f5517b9452d2c71b7c2b2e8e8d",
"pickrst_8h_source.html",
"structFIRSTPASS__INFO.html#a79971ac2f41950e2330721078f55cafd",
"structPRIMARY__RATE__CONTROL.html#adc72a4c5ff33b9f70c6fbf24f54d478a",
"structaom__codec__stream__info.html#af7487a0e56b6919f94a7e426abd44eac",
"structmacroblock.html#a33908adcf2dd14dc20fd4ae6695fbdb0"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> aom-docs-3.8.0-2-x86_64.pkg.tar.zst: usr/share/doc/aom/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "AOMedia AV1 Codec", "index.html", [
    [ "AOMedia Codec SDK", "index.html#aom_sdk", [
      [ "Introduction", "index.html#main_intro", null ],
      [ "Starting Points", "index.html#main_startpoints", null ]
    ] ],
    [ "AV1 Developer's Guide", "index.html#av1_guide", null ],
    [ "Support Options & FAQ", "index.html#main_support", null ],
    [ "RFC2119 Keywords", "rfc2119.html", [
      [ "MUST", "rfc2119.html#MUST", null ],
      [ "MUST NOT", "rfc2119.html#MUSTNOT", null ],
      [ "SHOULD", "rfc2119.html#SHOULD", null ],
      [ "SHOULD NOT", "rfc2119.html#SHOULDNOT", null ],
      [ "MAY", "rfc2119.html#MAY", null ]
    ] ],
    [ "CHANGELOG", "changelog.html", null ],
    [ "README.md", "readme.html", null ],
    [ "Usage", "usage.html", [
      [ "Important Data Types", "usage.html#usage_types", [
        [ "Contexts", "usage.html#usage_ctxs", null ],
        [ "Interfaces", "usage.html#usage_ifaces", null ]
      ] ],
      [ "Features", "usage.html#usage_features", null ],
      [ "Initialization", "usage.html#usage_init", null ],
      [ "Error Handling", "usage.html#usage_errors", null ],
      [ "Decoding", "usage_decode.html", [
        [ "Frame Iterator Based Decoding", "usage_decode.html#usage_frame_iter", null ]
      ] ],
      [ "Encoding", "usage_encode.html", null ]
    ] ],
    [ "AV1 DECODER GUIDE", "decoder_guide.html", null ],
    [ "AV1 ENCODER GUIDE", "encoder_guide.html", [
      [ "Introduction", "encoder_guide.html#architecture_introduction", [
        [ "Generic Block Transform Based Codecs", "encoder_guide.html#architecture_gencodecs", null ],
        [ "AV1 Structure and Complexity", "encoder_guide.html#architecture_av1_structure", null ]
      ] ],
      [ "The Libaom Command Line Interface", "encoder_guide.html#architecture_command_line", null ],
      [ "Main Encoder Data Structures", "encoder_guide.html#architecture_enc_data_structures", null ],
      [ "Encoder Use Cases", "encoder_guide.html#architecture_enc_use_cases", null ],
      [ "Speed vs Quality Trade Off", "encoder_guide.html#architecture_enc_speed_quality", null ],
      [ "Source Frame Processing", "encoder_guide.html#architecture_enc_src_proc", [
        [ "Main Data Structures", "encoder_guide.html#architecture_enc_frame_proc_data", null ],
        [ "Frame Ingest / Coding Pipeline", "encoder_guide.html#architecture_enc_frame_proc_ingest", null ],
        [ "Temporal Filtering", "encoder_guide.html#architecture_enc_frame_proc_tf", [
          [ "Overview", "encoder_guide.html#architecture_enc_frame_proc_tf_overview", null ],
          [ "Temporal Filtering Algorithm", "encoder_guide.html#architecture_enc_frame_proc_tf_algo", null ],
          [ "Temporal Filter Functions", "encoder_guide.html#architecture_enc_frame_proc_tf_funcs", null ]
        ] ],
        [ "Film Grain Modelling", "encoder_guide.html#architecture_enc_frame_proc_film", null ]
      ] ],
      [ "Rate Control", "encoder_guide.html#architecture_enc_rate_ctrl", [
        [ "Main Data Structures", "encoder_guide.html#architecture_enc_rate_ctrl_data", null ],
        [ "Supported Rate Control Options", "encoder_guide.html#architecture_enc_rate_ctrl_options", null ],
        [ "Variable Bitrate (VBR) Encoding", "encoder_guide.html#architecture_enc_vbr", [
          [ "1 Pass VBR Encoding", "encoder_guide.html#architecture_enc_1pass_vbr", null ],
          [ "2 Pass VBR Encoding", "encoder_guide.html#architecture_enc_2pass_vbr", null ],
          [ "1 Pass Lagged VBR Encoding", "encoder_guide.html#architecture_enc_1pass_lagged", null ]
        ] ],
        [ "The Main Rate Control Loop", "encoder_guide.html#architecture_enc_rc_loop", null ],
        [ "Fixed Q Mode", "encoder_guide.html#architecture_enc_fixed_q", null ]
      ] ],
      [ "GF/ ARF Frame Groups & Hierarchical Coding", "encoder_guide.html#architecture_enc_frame_groups", [
        [ "Main Data Structures", "encoder_guide.html#architecture_enc_frame_groups_data", null ],
        [ "Frame Groups", "encoder_guide.html#architecture_enc_frame_groups_groups", null ],
        [ "GF / ARF Group Length Determination", "encoder_guide.html#architecture_enc_gf_length", null ],
        [ "Defining a GF Group's Structure", "encoder_guide.html#architecture_enc_gf_structure", null ],
        [ "Key Frame Groups", "encoder_guide.html#architecture_enc_kf_groups", null ]
      ] ],
      [ "Temporal Dependency Modelling", "encoder_guide.html#architecture_enc_tpl", [
        [ "Configurations", "encoder_guide.html#architecture_enc_tpl_config", null ],
        [ "Algorithms", "encoder_guide.html#architecture_enc_tpl_algoritms", null ],
        [ "Key Functions and data structures", "encoder_guide.html#architecture_enc_tpl_keyfun", null ]
      ] ],
      [ "Block Partition Search", "encoder_guide.html#architecture_enc_partitions", null ],
      [ "Intra Mode Search", "encoder_guide.html#architecture_enc_intra_modes", null ],
      [ "Inter Prediction Mode Search", "encoder_guide.html#architecture_enc_inter_modes", null ],
      [ "Transform Search", "encoder_guide.html#architecture_enc_tx_search", null ],
      [ "Post Encode Loop Filtering", "encoder_guide.html#architecture_post_enc_filt", null ],
      [ "Entropy Coding", "encoder_guide.html#architecture_entropy", [
        [ "Arithmetic Coder", "encoder_guide.html#architecture_entropy_aritmetic", null ],
        [ "Transform Coefficient Coding and Optimization", "encoder_guide.html#architecture_entropy_coef", [
          [ "Transform coefficient coding", "encoder_guide.html#architecture_entropy_coef_what", [
            [ "Preparation - transform and quantize", "encoder_guide.html#architecture_entropy_coef_prepare", null ],
            [ "The coding process", "encoder_guide.html#architecture_entropy_coef_coding", null ],
            [ "Context information", "encoder_guide.html#architecture_entropy_coef_context", null ]
          ] ],
          [ "RD optimization", "encoder_guide.html#architecture_entropy_coef_rd", [
            [ "Entropy cost", "encoder_guide.html#architecture_entropy_coef_cost", null ],
            [ "Quantized level optimization", "encoder_guide.html#architecture_entropy_coef_opt", null ]
          ] ]
        ] ]
      ] ]
    ] ],
    [ "Sample Code", "samples.html", [
      [ "decode_to_md5", "example_decode_to_md5.html", null ],
      [ "decode_with_drops", "example_decode_with_drops.html", null ],
      [ "simple_decoder", "example_simple_decoder.html", null ],
      [ "lossless_encoder", "example_lossless_encoder.html", null ],
      [ "set_maps", "example_set_maps.html", null ],
      [ "simple_encoder", "example_simple_encoder.html", null ],
      [ "twopass_encoder", "example_twopass_encoder.html", null ],
      [ "scalable_encoder", "example_scalable_encoder.html", null ],
      [ "svc_encoder_rtc", "example_svc_encoder_rtc.html", null ],
      [ "aom_cx_set_ref", "example_aom_cx_set_ref.html", null ],
      [ "lightfield_encoder", "example_lightfield_encoder.html", null ],
      [ "lightfield_tile_list_decoder", "example_lightfield_tile_list_decoder.html", null ],
      [ "lightfield_decoder", "example_lightfield_decoder.html", null ],
      [ "lightfield_bitstream_parsing", "example_lightfield_bitstream_parsing.html", null ],
      [ "aomdec", "example_aomdec.html", null ],
      [ "aomenc", "example_aomenc.html", null ]
    ] ],
    [ "README.md", "LREADME.html", [
      [ "AV1 Codec Library", "LREADME.html#autotoc_md0", [
        [ "Contents", "LREADME.html#autotoc_md1", null ],
        [ "Building the library and applications", "LREADME.html#building-the-library-and-applications", [
          [ "Prerequisites", "LREADME.html#prerequisites", null ],
          [ "Get the code", "LREADME.html#get-the-code", null ],
          [ "Basic build", "LREADME.html#basic-build", null ],
          [ "Configuration options", "LREADME.html#configuration-options", null ],
          [ "Dylib builds", "LREADME.html#dylib-builds", null ],
          [ "Debugging", "LREADME.html#debugging", null ],
          [ "Cross compiling", "LREADME.html#cross-compiling", null ],
          [ "Sanitizers", "LREADME.html#sanitizers", null ],
          [ "Microsoft Visual Studio builds", "LREADME.html#microsoft-visual-studio-builds", null ],
          [ "Xcode builds", "LREADME.html#xcode-builds", null ],
          [ "Emscripten builds", "LREADME.html#emscripten-builds", null ],
          [ "Extra build flags", "LREADME.html#extra-build-flags", null ],
          [ "Build with VMAF support", "LREADME.html#build-with-vmaf", null ]
        ] ],
        [ "Testing the AV1 codec", "LREADME.html#testing-the-av1-codec", [
          [ "Testing basics", "LREADME.html#testing-basics", [
            [ "1. Unit tests:", "LREADME.html#unit-tests", null ],
            [ "2. Example tests:", "LREADME.html#example-tests", null ],
            [ "3. Encoder tests:", "LREADME.html#encoder-tests", null ]
          ] ],
          [ "IDE hosted tests", "LREADME.html#ide-hosted-tests", null ],
          [ "Downloading the test data", "LREADME.html#downloading-the-test-data", null ],
          [ "Adding a new test data file", "LREADME.html#adding-a-new-test-data-file", null ],
          [ "Additional test data", "LREADME.html#additional-test-data", null ],
          [ "Sharded testing", "LREADME.html#sharded-testing", [
            [ "1. Running test_libaom directly:", "LREADME.html#running-test_libaom-directly", null ],
            [ "2. Running the tests via the CMake build:", "LREADME.html#running-the-tests-via-the-cmake-build", null ]
          ] ]
        ] ],
        [ "Coding style", "LREADME.html#coding-style", null ],
        [ "Submitting patches", "LREADME.html#submitting-patches", [
          [ "Login cookie", "LREADME.html#login-cookie", null ],
          [ "Contributor agreement", "LREADME.html#contributor-agreement", null ],
          [ "Testing your code", "LREADME.html#testing-your-code", null ],
          [ "Commit message hook", "LREADME.html#commit-message-hook", null ],
          [ "Upload your change", "LREADME.html#upload-your-change", null ],
          [ "Incorporating reviewer comments", "LREADME.html#incorporating-reviewer-comments", null ],
          [ "Submitting your change", "LREADME.html#submitting-your-change", null ],
          [ "Viewing the status of uploaded changes", "LREADME.html#viewing-the-status-of-uploaded-changes", null ]
        ] ],
        [ "Support", "LREADME.html#support", null ],
        [ "Bug reports", "LREADME.html#bug-reports", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"LREADME.html",
"encoder_guide.html#architecture_enc_gf_structure",
"group__aom__encoder.html#ga758649aa6cd9fefb15ad888489884a38",
"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca413c6090fa855359106e32fbd2b5f668",
"group__tpl__modelling.html#ga3d123b0f3781dcb06c5f4d053ac3655b",
"structAV1__COMP.html#a79d3369ac3e0d4a9461c133a285a417f",
"structCommonQuantParams.html#ae6b10a492cbf8dd0501129c7d264ee6d",
"structMB__MODE__INFO.html#a13f1a883e73c4b721c2212d0416b3967",
"structRestorationInfo.html#a6b8daa3388a9cacec495eb2d8ab88436",
"structaom__codec__enc__cfg.html#ae55d1533084ea0090588dc1187baffb5",
"structinter__modes__info.html#afa119f92044ae1a737bab446bade8c88"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
